@@ -1,6 +1,7 @@
 """Entry file for the CLI, which aggregates and aliases all commands."""
 
 import sys
+from importlib.metadata import PackageNotFoundError, version
 
 import typer
 
@@ -21,7 +22,23 @@ from dayhoff_tools.warehouse import (
     import_from_warehouse_typer,
 )
 
-app = typer.Typer()
+
+def _get_dht_version() -> str:
+    try:
+        return version("dayhoff-tools")
+    except PackageNotFoundError:
+        # Fallback to package __version__ if running from source
+        try:
+            from dayhoff_tools import __version__  # type: ignore
+
+            return __version__
+        except Exception:
+            return "unknown"
+
+
+app = typer.Typer(
+    help=f"Dayhoff Tools (dh) v{_get_dht_version()}\n\nUse 'dh --version' to print version and exit."
+)
 
 # Utility commands
 app.command("clean")(delete_local_branch)
@@ -50,6 +67,27 @@ app.add_typer(engine_app, name="engine", help="Manage compute engines for develo
 app.add_typer(studio_app, name="studio", help="Manage persistent development studios.")
 
 
+@app.callback(invoke_without_command=True)
+def _version_option(
+    ctx: typer.Context,
+    version_flag: bool = typer.Option(
+        False,
+        "--version",
+        "-v",
+        help="Print version and exit.",
+        is_eager=True,
+    ),
+):
+    """Global options for the dh CLI (e.g., version)."""
+    if version_flag:
+        typer.echo(_get_dht_version())
+        raise typer.Exit()
+    # If no subcommand provided, show help instead of 'Missing command'
+    if ctx.invoked_subcommand is None:
+        typer.echo(ctx.get_help())
+        raise typer.Exit()
+
+
 @app.command("wheel")
 def build_and_upload_wheel_command(
     bump: str = typer.Option(
